@@ -60,7 +60,7 @@ class HonParameterRange(HonParameter):
 
     @value.setter
     def value(self, value):
-        if self._min < value < self._max and not value % self._step:
+        if self._min <= value <= self._max and not value % self._step:
             self._value = self._value
         else:
             raise ValueError(f"min {self._min} max {self._max} step {self._step}")
@@ -78,7 +78,7 @@ class HonParameterEnum(HonParameter):
 
     @property
     def values(self):
-        return self._values
+        return [str(value for value in self._values]
 
     @property
     def value(self):
